EngineOilUtils = {
    MOD_NAME = g_currentModName, MOD_DIR = g_currentModDirectory
}

function EngineOilUtils.getConfigurationsFromXML(xmlFile, superfunc, key,
                                                 baseDir, customEnvironment,
                                                 isMod, storeItem)
    local configurations, defaultConfigurationIds =
        superfunc(xmlFile, key, baseDir, customEnvironment, isMod, storeItem)
    if configurations ~= nil and xmlFile:hasProperty("vehicle.fillUnit") and
        xmlFile:hasProperty("vehicle.motorized") and
        xmlFile:hasProperty("vehicle.enterable") and
        xmlFile:hasProperty("vehicle.drivable") and
        EngineOilUtils.getIsDieselVehicle(xmlFile) then
        configurations["engineOilAddon"] = {
            {
                isDefault = false,
                saveId = "1",
                isSelectable = true,
                index = 1,
                dailyUpkeep = 0,
                price = 0,
                name = g_i18n:getText("configuration_valueYes"),
                nameCompareParams = {}
            }, {
                isDefault = true,
                saveId = "2",
                isSelectable = true,
                index = 2,
                dailyUpkeep = 0,
                name = g_i18n:getText("configuration_valueNo"),
                price = 0,
                nameCompareParams = {}
            }
        }
    end
    return configurations, defaultConfigurationIds
end

function EngineOilUtils.getTimeFormatted(minutes)
    return g_i18n:formatMinutes(minutes)
    -- if minutes ~= nil then
    --     local hours = math.floor(minutes / 60)
    --     minutes = math.floor((minutes - hours * 60) / 6)
    --     local minutesString = string.format("%01d", minutes) -- *10
    --     return hours .. "." .. minutesString
    -- else
    --     return g_i18n:getText("ui_hours_none")
    -- end
end

function EngineOilUtils.getIsDieselVehicle(xmlFile)
    local confInd = 0
    local consInd = 0

    while true do
        local key = string.format(
                        "vehicle.motorized.consumerConfigurations.consumerConfiguration(%d)",
                        confInd)
        if not xmlFile:hasProperty(key) then break end

        while true do
            local consumerKey = string.format(".consumer(%d)", consInd)
            if not xmlFile:hasProperty(key .. consumerKey) then break end

            local fillTypeName = xmlFile:getValue(
                                     key .. consumerKey .. "#fillType", "diesel")

            if fillTypeName == "diesel" then return true end
            consInd = consInd + 1
        end
        confInd = confInd + 1
    end
    return false
end

function EngineOilUtils.storePack()
    local modDesc = loadXMLFile("ModFile", EngineOilUtils.MOD_DIR .. "modDesc.xml")
    local key = string.format("modDesc.storePacks.storePack")
    local name = getXMLString(modDesc, key .. "#name")
    local title = getXMLString(modDesc, key .. "#title")
    local imageFilename = getXMLString(modDesc, key .. "#image")
    if title ~= nil and title:sub(1, 6) == "$l10n_" then
        title = g_i18n:getText(title:sub(7))
    end
    delete(modDesc)
    g_storeManager:addPack(name, title, imageFilename, EngineOilUtils.MOD_DIR)
end


EngineOilUtils.storePack()